"""Create clean and "enriched" chunks"""

# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/04_chunkr.ipynb.

# %% auto 0
__all__ = ['mistral_api_key']

# %% ../nbs/04_chunkr.ipynb 2
import os
import re
import time
from io import BytesIO
from dotenv import load_dotenv
import base64
from fastcore.all import *
from rich import print

import pandas as pd
from mistralai import Mistral
from PIL import Image
# from tqdm import tqdm

from .readers import load_evals


# %% ../nbs/04_chunkr.ipynb 3
load_dotenv()
mistral_api_key = os.getenv("MISTRAL_API_KEY")
